==> igniteui-webcomponents-core-3.2.4.tgz: package/esm2015/lib/WebTabHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebTabHeaderElementDescriptionMetadata } from "./WebTabHeaderElementDescriptionMetadata";
import { WebTabHeaderConnectionEventArgsDescription } from "./WebTabHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
export let WebTabHeaderConnectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabHeaderConnectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabHeaderConnectionEventArgsDescriptionMetadata.a == null) {
                WebTabHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabHeaderConnectionEventArgsDescriptionMetadata.c(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebTabHeaderConnectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
            WebContentPaneDescriptionMetadata.d(a);
            WebTabHeaderElementDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabHeaderConnectionEventArgs");
            a.item("Pane", "ExportedType:WebContentPane");
            a.item("Element", "ExportedType:WebTabHeaderElement");
        }
        static d(a) {
            WebTabHeaderConnectionEventArgsDescriptionMetadata.b(a);
            a.u("WebTabHeaderConnectionEventArgs", () => new WebTabHeaderConnectionEventArgsDescription());
            a.t("WebTabHeaderConnectionEventArgs", WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        }
    }
    WebTabHeaderConnectionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabHeaderConnectionEventArgsDescriptionMetadata, 'WebTabHeaderConnectionEventArgsDescriptionMetadata');
    WebTabHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebTabHeaderConnectionEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebTabHeaderConnectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebTabHeaderElementDescriptionMetadata } from "./WebTabHeaderElementDescriptionMetadata";
import { WebTabHeaderConnectionEventArgsDescription } from "./WebTabHeaderConnectionEventArgsDescription";
/**
 * @hidden
 */
export let WebTabHeaderConnectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabHeaderConnectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabHeaderConnectionEventArgsDescriptionMetadata.a == null) {
                WebTabHeaderConnectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabHeaderConnectionEventArgsDescriptionMetadata.c(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebTabHeaderConnectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
            WebContentPaneDescriptionMetadata.d(a);
            WebTabHeaderElementDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabHeaderConnectionEventArgs");
            a.item("Pane", "ExportedType:WebContentPane");
            a.item("Element", "ExportedType:WebTabHeaderElement");
        }
        static d(a) {
            WebTabHeaderConnectionEventArgsDescriptionMetadata.b(a);
            a.aa("WebTabHeaderConnectionEventArgs", () => new WebTabHeaderConnectionEventArgsDescription());
            a.z("WebTabHeaderConnectionEventArgs", WebTabHeaderConnectionEventArgsDescriptionMetadata.a);
        }
    }
    WebTabHeaderConnectionEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebTabHeaderConnectionEventArgsDescriptionMetadata, 'WebTabHeaderConnectionEventArgsDescriptionMetadata');
    WebTabHeaderConnectionEventArgsDescriptionMetadata.a = null;
    return WebTabHeaderConnectionEventArgsDescriptionMetadata;
})();
